@@ -51,7 +51,7 @@ RETRY = {
     "connect": 5,
     "read": 3,
     "redirect": 5,
-    "method_whitelist": frozenset(
+    "allowed_methods": frozenset(
         ["HEAD", "GET", "PUT", "DELETE", "OPTIONS", "TRACE", "POST"]
     ),
     "status_forcelist": frozenset([502, 503, 504]),
@@ -126,6 +126,11 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         self.retry = RETRY
         for k, v in kwargs.items():
             if k.startswith("retry_"):
+
+                # `method_whitelist` has been deprecated
+                if k == "retry_method_whitelist":
+                    k = "retry_allowed_methods"
+
                 self.retry[k.replace("retry_", "")] = v
 
         # default timeout
@@ -270,7 +275,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         try:
             r = session.post(url, data=data, timeout=self.timeout_secs)
         except self._requests.exceptions.RetryError as ex:
-            raise RetryError(None, ex[0])
+            raise RetryError(None, ex.args[0])
         except Exception as ex:
             log.debug("unable to connect to the Squirro platform: %r", ex)
             raise ConnectionError(None, ex)
@@ -358,7 +363,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
             try:
                 res = func(url, timeout=self.timeout_secs, **kwargs)
             except self._requests.exceptions.RetryError as ex:
-                raise RetryError(None, ex[0])
+                raise RetryError(None, ex.args[0])
 
             # check for failed authorization
             if retry_count == 0 and res.status_code == 401:
