@@ -1,6 +1,7 @@
 # encoding: utf-8
 
 import json
+import logging
 import sys
 
 from ..util import deprecation
@@ -67,8 +68,8 @@ class TopicApiBaseMixin(object):
         Example::
 
             >>> client.get_pipelets()
-            {u'pipelets': [{u'id': u'tenant01/textrazor',
-                            u'name': u'textrazor'}]}
+            {'pipelets': [{'id': 'tenant01/textrazor',
+                            'name': 'textrazor'}]}
         """
         url = "%(ep)s/v0/%(tenant)s/pipelets" % {
             "ep": self.topic_api_url,
@@ -85,12 +86,12 @@ class TopicApiBaseMixin(object):
         Example::
 
             >>> client.get_pipelet('textrazor')
-            {u'description': u'Entity extraction with `TextRazor`.',
-             u'description_html': u'<p>Entity extraction with
-             u'<code>TextRazor</code>.</p>',
-             u'id': u'tenant01/textrazor',
-             u'name': u'textrazor',
-             u'source': u'from squirro.sdk.pipelet import PipeletV1\n\n\n...'}
+            {'description': 'Entity extraction with `TextRazor`.',
+             'description_html': '<p>Entity extraction with
+             '<code>TextRazor</code>.</p>',
+             'id': 'tenant01/textrazor',
+             'name': 'textrazor',
+             'source': 'from squirro.sdk.pipelet import PipeletV1\n\n\n...'}
         """
         url = "%(ep)s/v0/%(tenant)s/pipelets/%(name)s" % {
             "ep": self.topic_api_url,
@@ -167,7 +168,7 @@ class TopicApiBaseMixin(object):
             >>> client.get_encrypted_query(
                     '2aEVClLRRA-vCCIvnuEAvQ',
                     query='test_query')
-            {u'encrypted_query': 'YR4h147YAldsARmTmIrOcJqpuntiJULXPV3ZrX_'
+            {'encrypted_query': 'YR4h147YAldsARmTmIrOcJqpuntiJULXPV3ZrX_'
             'blVWvbCavvESTw4Jis6sTgGC9a1LhrLd9Nq-77CNX2eeieMEDnPFPRqlPGO8V'
             'e2rlwuKuVQJGQx3-F_-eFqF-CE-uoA6yoXoPyYqh71syalWFfc-tuvp0a7c6e'
             'eKAO6hoxwNbZlb9y9pha0X084JdI-_l6hew9XKZTXLjT95Pt42vmoU_t6vh_w1'
@@ -283,6 +284,12 @@ class TopicApiBaseMixin(object):
             "created_after": created_after,
             "encrypted_query": encrypted_query,
         }
+        if "scroll" in kwargs:
+            logging.warning(
+                "Wrong usage of `scroll` parameter! Has no effect for `query` method since v3.3.8. "
+                "Use `scan` method to perform scrolling."
+            )
+            kwargs.pop("scroll")
         args.update(kwargs)
         data = dict([(k, v) for k, v in list(args.items()) if v is not None])
 
@@ -1043,7 +1050,7 @@ class TopicApiBaseMixin(object):
         project_id,
         query=None,
         scroll="5m",
-        count=10000,
+        count=1000,
         fields=None,
         highlight=None,
         created_before=None,
@@ -1091,6 +1098,13 @@ class TopicApiBaseMixin(object):
             - ensure this works for encrypted queries too.
             - support fold_near_duplicate option
             - support smart filter queries with more than 10k results
+
+        Example::
+
+        >>> for item in client.scan(project_id='Sz7LLLbyTzy_SddblwIxaA', query='country:CH AND plants',
+        ...                         count=500, scroll='1m'):
+                # process matched item
+
         """
         assert scroll, "`scroll` cannot be empty for scan."
         if options:
@@ -1148,30 +1162,30 @@ class TopicApiBaseMixin(object):
         Example::
 
             >>> client.get_items('2aEVClLRRA-vCCIvnuEAvQ', count=1)
-            {u'count': 1,
-             u'eof': False,
-             u'items': [{u'created_at': u'2012-10-06T08:27:58',
-                         u'id': u'haG6fhr9RLCm7ZKz1Meouw',
-                         u'link': u'https://www.youtube.com/...',
-                         u'read': True,
-                         u'item_score': 0.5,
-                         u'score': 0.56,
-                         u'sources': [{u'id': u'oMNOQ-3rQo21q3UmaiaLHw',
-                                       u'link': u'https://gdata.youtube...',
-                                       u'provider': u'feed',
-                                       u'title': u'Uploads by mymemonic'},
-                                      {u'id': u'H4nd0CasQQe_PMNDM0DnNA',
-                                       u'link': None,
-                                       u'provider': u'savedsearch',
-                                       u'title': u'Squirro Alerts for "mmonic"'
+            {'count': 1,
+             'eof': False,
+             'items': [{'created_at': '2012-10-06T08:27:58',
+                         'id': 'haG6fhr9RLCm7ZKz1Meouw',
+                         'link': 'https://www.youtube.com/...',
+                         'read': True,
+                         'item_score': 0.5,
+                         'score': 0.56,
+                         'sources': [{'id': 'oMNOQ-3rQo21q3UmaiaLHw',
+                                       'link': 'https://gdata.youtube...',
+                                       'provider': 'feed',
+                                       'title': 'Uploads by mymemonic'},
+                                      {'id': 'H4nd0CasQQe_PMNDM0DnNA',
+                                       'link': None,
+                                       'provider': 'savedsearch',
+                                       'title': 'Squirro Alerts for "mmonic"'
                                       }],
-                         u'starred': False,
-                         u'thumbler_url': u'[long url]...jpg',
-                         u'title': u'Web Clipping - made easy with Memonic',
-                         u'webshot_height': 360,
-                         u'webshot_url': u'http://webshot.trunk....jpg',
-                         u'webshot_width': 480}],
-             u'now': u'2012-10-11T14:39:54'}
+                         'starred': False,
+                         'thumbler_url': '[long url]...jpg',
+                         'title': 'Web Clipping - made easy with Memonic',
+                         'webshot_height': 360,
+                         'webshot_url': 'http://webshot.trunk....jpg',
+                         'webshot_width': 480}],
+             'now': '2012-10-11T14:39:54'}
 
         """
         deprecation("Please use the query method instead.")
@@ -1201,27 +1215,27 @@ class TopicApiBaseMixin(object):
 
             >>> client.get_item(
             ...     '2aEVClLRRA-vCCIvnuEAvQ', 'haG6fhr9RLCm7ZKz1Meouw')
-            {u'item': {u'created_at': u'2012-10-06T08:27:58',
-                       u'id': u'haG6fhr9RLCm7ZKz1Meouw',
-                       u'link': u'https://www.youtube.com/watch?v=Zzvhu42dWAc',
-                       u'read': True,
-                       u'item_score': 0.5,
-                       u'score': 0.56,
-                       u'sources': [{u'id': u'oMNOQ-3rQo21q3UmaiaLHw',
-                                     u'link': u'https://gdata.youtube.com/...',
-                                     u'provider': u'feed',
-                                     u'title': u'Uploads by mymemonic'},
-                                    {u'id': u'H4nd0CasQQe_PMNDM0DnNA',
-                                     u'link': None,
-                                     u'provider': u'savedsearch',
-                                     u'title': u'Squirro Alerts for "memonic"'}
+            {'item': {'created_at': '2012-10-06T08:27:58',
+                       'id': 'haG6fhr9RLCm7ZKz1Meouw',
+                       'link': 'https://www.youtube.com/watch?v=Zzvhu42dWAc',
+                       'read': True,
+                       'item_score': 0.5,
+                       'score': 0.56,
+                       'sources': [{'id': 'oMNOQ-3rQo21q3UmaiaLHw',
+                                     'link': 'https://gdata.youtube.com/...',
+                                     'provider': 'feed',
+                                     'title': 'Uploads by mymemonic'},
+                                    {'id': 'H4nd0CasQQe_PMNDM0DnNA',
+                                     'link': None,
+                                     'provider': 'savedsearch',
+                                     'title': 'Squirro Alerts for "memonic"'}
                                    ],
-                       u'starred': False,
-                       u'thumbler_url': u'[long url]...jpg',
-                       u'title': u'Web Clipping - made easy with Memonic',
-                       u'webshot_height': 360,
-                       u'webshot_url': u'http://webshot.trunk....jpg',
-                       u'webshot_width': 480}}
+                       'starred': False,
+                       'thumbler_url': '[long url]...jpg',
+                       'title': 'Web Clipping - made easy with Memonic',
+                       'webshot_height': 360,
+                       'webshot_url': 'http://webshot.trunk....jpg',
+                       'webshot_width': 480}}
 
         """
 
@@ -1482,8 +1496,15 @@ class TopicApiBaseMixin(object):
         :param max_suggestions: Maximum number of typeahead suggestions to be
             returned. `max_suggestions` should be a non-negative integer.
         :param options: Dictionary of options that influence the result-set.
-            Valid options are: `template_params` dict containing the query
-            template parameters
+            Valid options are:
+            - `template_params` dict containing the query template parameters
+            - `select_suggesters` (optional) list containing suggesters to be used.
+                If no suggesters are selected, all suggesters are executed by default.
+                Available suggesters: ["facet_value", "facet_name", "content_phrase", "saved_search"]
+                - "facet_value": Complete on facet-values that have "autocomplete" enabled (Exact Search)
+                - "facet_name: Help to find the correct facet
+                - "content_phrase": Complete on key-phrases + item-title (Fuzzy Search) added via NLP-Tagger
+                - "saved_search": Complete on queries saved by the user
         :param filter_query: Squirro query to limit the typeahead suggestions.
             Must be of type `string`. Defaults to `None` if not specified. As
             an example, this parameter can be used to filter the typeahead
@@ -1493,23 +1514,55 @@ class TopicApiBaseMixin(object):
 
         Example::
 
-            >>> client.get_typeahead_suggestions(
-                    project_id='Sz7LLLbyTzy_SddblwIxaA',
-                    'searchbar_query='Country:India c',
-                    'cursor_pos'=15)
+            # Default usage
 
-                {u'suggestions': [{
-                    u'type': u'facetvalue', u'key': u'Country:India
-                    City:Calcutta', u'value': u'city:Calcutta', 'score': 12,
-                    'cursor_pos': 26, 'group': 'country'},
+            >>> client.get_typeahead_suggestions(project_id='Sz7LLLbyTzy_SddblwIxaA',
+            ...                                 searchbar_query='Country:India c',
+            ...                                 cursor_pos=15)
+            {'suggestions': [
+                {'type': 'facetvalue', 'key': 'Country:India
+                City:Calcutta', 'value': 'city:Calcutta', 'score': 12,
+                'cursor_pos': 26, 'group': 'country'},
+                {'type': 'facetvalue', 'key': 'Country:India
+                Name:Caesar', 'value': 'name:Caesar', 'score': 8,
+                'cursor_pos': 24, 'group': 'country'},
+                {'type': 'facetname', 'key': 'Country:India city:',
+                'value': 'City', 'score': 6, 'cursor_pos': 19, 'group':
+                'Fields'}
+            ]}
 
-                    {u'type': u'facetvalue', u'key': u'Country:India
-                    Name:Caesar', u'value': u'name:Caesar', 'score': 8,
-                    'cursor_pos': 24, 'group': 'country'},
 
-                    {u'type': u'facetname', u'key': u'Country:India city:',
-                    u'value': u'City', 'score': 6, 'cursor_pos': 19, 'group':
-                    'Fields'}]}
+        Example::
+
+            # Autocomplete on one specific suggester like `content_phrase`
+            # - The "content_phrase" suggester completes on key-phrases and item titles added by
+            #  `NLP-Tagger <https://squirro.atlassian.net/wiki/spaces/DOC/pages/2396061784/Content-based+Typeahead>`__
+            # - Autocompletion supports in-order phrase & fuzzy string matching
+            # - Highlighted tokens are returned as <b> html tags (highlight_cursor_start/end is not used)
+
+            >>> client.get_typeahead_suggestions(project_id=project_id,
+            ...         searchbar_query="pla",
+            ...         cursor_pos=0, # cursor_pos not used for this suggester, but parameter is required on API level
+            ...         options={"select_suggesters": ["content_phrase"]})
+            {"suggestions":[
+                  {
+                     "type":"text",
+                     "key":" \"plant material\"",
+                     "value":"<b>plant</b> material",
+                     "group_name":"By Content",
+                     "highlight_cursor_start":0,
+                     "highlight_cursor_end":0
+                  },
+                  {
+                     "type":"text",
+                     "key":" \"plant proteins\"",
+                     "value":"<b>plant</b> proteins",
+                     "group_name":"By Content",
+                     "highlight_cursor_start":0,
+                     "highlight_cursor_end":0
+                  }]
+            }
+
         """
 
         # construct the url
