@@ -12,6 +12,7 @@ class ProjectsMixin(object):
         [
             "default_search",
             "title",
+            "description",
             "default_sort",
             "locator",
             "guide_completed_steps",
@@ -75,6 +76,7 @@ class ProjectsMixin(object):
     def new_project(
         self,
         title,
+        description=None,
         owner_id=None,
         locator=None,
         default_sort=None,
@@ -84,6 +86,7 @@ class ProjectsMixin(object):
         """Create a new project.
 
         :param title: Project title.
+        :param description: Project description (optional).
         :param owner_id: User identifier which owns the objects.
         :param locator: Custom index locator configuration which is a
             dictionary which contains the `index_server` (full URI including
@@ -108,6 +111,7 @@ class ProjectsMixin(object):
             >>> default_sort = [{'relevance': {'order': 'asc'}}]
             >>> client.new_project(
                     'My Project',
+                    description=description,
                     locator=locator,
                     default_sort=default_sort,
                     photo='https://twitter.com/Cristiano/photo',
@@ -125,6 +129,8 @@ class ProjectsMixin(object):
         data = {"title": title}
         if project_id is not None:
             data["project_id"] = project_id
+        if description is not None:
+            data["description"] = description
         if owner_id is not None:
             data["owner_id"] = owner_id
         if locator is not None:
@@ -140,6 +146,7 @@ class ProjectsMixin(object):
     def new_project_from_template(
         self,
         title,
+        description=None,
         locator=None,
         template_name=None,
         template_path=None,
@@ -171,10 +178,12 @@ class ProjectsMixin(object):
         import_trends=True,
         import_items=True,
         import_guide_file=True,
+        import_ais_published_models=True,
     ):
         """Create a new project from a project template.
 
         :param title: Project title.
+        :param description: Project description.
         :param locator: Custom index locator configuration which is a
             dictionary which contains the `index_server` (full URI including
             the port for index server) key.
@@ -253,7 +262,9 @@ class ProjectsMixin(object):
             defaults to `True`. Needs the `import_facets` to be set to `True`
             also.
         :param import_guide_file: Boolean. Whether to include the project
-            project guide file, defaults to `True`.
+            guide file, defaults to `True`.
+        :param import_ais_published_models: Boolean. Whether to include the
+            ais published models, defaults to `True`.
         :returns: A dictionary which contains the project identifier.
 
         Example::
@@ -271,6 +282,8 @@ class ProjectsMixin(object):
 
         # build data
         data = {"title": title}
+        if description is not None:
+            data["description"] = description
         if template_name is not None:
             data["template_name"] = template_name
         if template_path is not None:
@@ -311,6 +324,7 @@ class ProjectsMixin(object):
             "import_items": import_items,
             "import_synonyms": import_synonyms,
             "import_guide_file": import_guide_file,
+            "import_ais_published_models": import_ais_published_models,
         }
         data["import_options"] = json.dumps(import_options)
 
@@ -456,6 +470,7 @@ class ProjectsMixin(object):
         export_sources_dataloader_plugins=True,
         export_trends=True,
         export_guide_file=True,
+        export_ais_published_models=True,
         export_items=False,
         export_items_config=None,
     ):
@@ -551,6 +566,8 @@ class ProjectsMixin(object):
         :param export_items_config: Dict. Containing the query parameters that
             can be used to filter down the exported items. Currently only
             `query` and `count` parameters are supported.
+        :param export_ais_published_models: Boolean. Whether to include
+            the published ml models, defaults to `True`.
         :return: Returns a dictionary containing the API response data and
             headers.
 
@@ -598,6 +615,7 @@ class ProjectsMixin(object):
             "export_trends": export_trends,
             "export_guide_file": export_guide_file,
             "export_items": export_items,
+            "export_ais_published_models": export_ais_published_models,
             "export_synonyms": export_synonyms,
             "export_items_config": export_items_config,
         }
@@ -696,6 +714,7 @@ class ProjectsMixin(object):
         import_trends=True,
         import_items=True,
         import_guide_file=True,
+        import_ais_published_models=True,
     ):
 
         """Imports parts or all configuration and metadata of a project.
@@ -785,6 +804,8 @@ class ProjectsMixin(object):
             also.
         :param import_guide_file: Boolean. Whether to include the project guide file,
             defaults to `True`.
+        :param import_ais_published_models: Boolean. Whether to include the ais published models,
+            defaults to `True`.
         :return: Returns a dictionary containing the API response data and
             headers.
 
@@ -831,6 +852,7 @@ class ProjectsMixin(object):
             "import_items": import_items,
             "import_synonyms": import_synonyms,
             "import_guide_file": import_guide_file,
+            "import_ais_published_models": import_ais_published_models,
         }
         import_options["token"] = self.refresh_token
 
